@@ -2,7 +2,7 @@ package PICA::Parser::Plain;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use charnames ':full';
 use Carp qw(croak);
@@ -13,7 +13,7 @@ sub SUBFIELD_INDICATOR { '$' }
 sub END_OF_FIELD       { "\N{LINE FEED}" }
 sub END_OF_RECORD      { "\N{LINE FEED}" }
 
-sub next_record {
+sub _next_record {
     my ($self) = @_;
 
     my $plain = undef;
