@@ -2,7 +2,7 @@ package PICA::Parser::Plus;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use charnames qw(:full);
 use Carp qw(croak);
@@ -13,7 +13,7 @@ sub SUBFIELD_INDICATOR { "\N{INFORMATION SEPARATOR ONE}" }
 sub END_OF_FIELD       { "\N{INFORMATION SEPARATOR TWO}" }
 sub END_OF_RECORD      { "\N{LINE FEED}" }
 
-sub next_record {
+sub _next_record {
     my ($self) = @_;
      
     # TODO: does only work if END_OF_RECORD is LINE FEED
