@@ -2,7 +2,7 @@ package PICA::Parser::XML;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Carp qw(croak);
 use XML::LibXML::Reader;
@@ -39,7 +39,7 @@ sub new {
     $self;
 }
 
-sub next_record {
+sub _next_record {
     my ($self) = @_;
 
     my $reader = $self->{xml_reader};
